@@ -21,14 +21,6 @@ Sjis-JA - "Yet Another JPerl" Source code filter to escape ShiftJIS (Japanese do
 
        no Sjis; ͗pł܂B
 
-      g֐
-        Sjis::ord(...);
-        Sjis::reverse(...);
-        Sjis::length(...);
-        Sjis::substr(...);
-        Sjis::index(...);
-        Sjis::rindex(...);
-
     R}hvvgňȉ̂悤Ɏs
       perl     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
       perl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
@@ -39,6 +31,14 @@ Sjis-JA - "Yet Another JPerl" Source code filter to escape ShiftJIS (Japanese do
       ? * găChJ[h̎w肪ł܂
       ' ` ' găNH[g邱Ƃł܂
 
+      g֐
+        Sjis::ord(...);
+        Sjis::reverse(...);
+        Sjis::length(...);
+        Sjis::substr(...);
+        Sjis::index(...);
+        Sjis::rindex(...);
+
    g: B
 
     R}hvvgňȉ̂悤Ɏs
@@ -56,7 +56,13 @@ Sjis-JA - "Yet Another JPerl" Source code filter to escape ShiftJIS (Japanese do
 Kpł悤ɂȂ܂B
 
 Perl5.8 ȍ~ Encode W[ɂă}`KT|[gꂽ߁A
-jperl ͕svɂȂƌĂ܂BłA͖{Ȃ̂ł傤H
+jperl ͕svɂȂƌĂ܂B
+
+JPerl in CPAN Perl Ports (Binary Distributions)
+
+http://www.cpan.org/ports/index.html#jperl
+
+łA͖{Ȃ̂ł傤H
 
 {ɂāAėp^Rs[^̓óAp[\iRs[^̓R[
 hѓóAɂ͌gѓdbɎ܂ŁAShiftJIS {ƂR[h
@@ -141,20 +147,26 @@ http://mail.pm.org/pipermail/tokyo-pm/1999-September/001854.html
 AFilter::Util::Call 𗘗pĂȂ_APerl ̍\͂ĕKvɉ
 GXP[v_قȂ܂B
 
-=head1 CXg[@
+=head1 CXg[@(makegꍇ)
 
-   perl Makefile.pl         --- Makefile.pl  make.bat 𐶐܂
-   make.bat install
-   make.bat test
+   perl Makefile.PL
+   make test
+   make install
 
-   make.bat install         --- ݎgp perl ɃCXg[܂
-   perl58 make.bat install  --- perl5.008 ɃCXg[܂
-   perl510 make.bat install --- perl5.010 ɃCXg[܂
-   perl512 make.bat install --- perl5.012 ɃCXg[܂
-   perl64  make.bat install --- perl64    ɃCXg[܂
+=head1 CXg[@(makegȂꍇ)
 
-   make.bat dist            --- CPAN zzppbP[W܂
-   make.bat tar.bat         --- tar.bat 쐬܂
+   perl pMakefile.pl         --- pMakefile.pl  pmake.bat 𐶐܂
+   pmake.bat
+   pmake.bat test
+
+   pmake.bat install          --- ݎgp perl ɃCXg[܂
+   perl58   pmake.bat install --- perl5.008 ɃCXg[܂
+   perl510  pmake.bat install --- perl5.010 ɃCXg[܂
+   perl512  pmake.bat install --- perl5.012 ɃCXg[܂
+   perl64   pmake.bat install --- perl64    ɃCXg[܂
+
+   pmake.bat dist             --- CPAN zzppbP[W܂
+   pmake.bat ptar.bat         --- ptar.bat 쐬܂
 
 =head1 \tgEFÄꗗ
 
@@ -165,13 +177,77 @@ GXP[v_قȂ܂B
    perl512.bat      --- ϐ PATH ̐ݒȂ perl5.12 TĎs
    perl64.bat       --- ϐ PATH ̐ݒȂ perl64   TĎs
 
-=head1 NX̒`
+=head1 GXP[vɂʌ݊̊m
+
+̃\tgEFA͉ߋ̂̂󂵂͂AɁuGXP[vvɂċ@\ǉ
+Ă܂B獡܂ŉ\łƂs\ɂȂ邱Ƃ͂܂B
+̃Av[`́AނċȂɗLłB_Perlɖ
+łƂ͌Ȃ̂łB
+
+=head1 XNvg̃GXP[v
+
+쐬XNvg 'use Sjis;' ƏKv܂B
+
+  ---------------------------------
+  ȑO        Ȍ
+  ---------------------------------
+  use utf8;   use Sjis;
+  ---------------------------------
+
+=head1 }`oCg̃GXP[v
+
+̃\tgEFAɂāA}`oCg̑2oCg @  [  \  ]  ^  `  {  |  }
+̒O chr(0x5c) }܂BΏۂ͈ȉ̉ӏłB
+
+=over 2
+
+=item * VONH[g̕ ('', q{}, <<'END' and qw{})
+
+=item * _uNH[g̕ ("", qq{}, <<END, <<"END", ``, qx{} and <<`END`)
+
+=item * VONH[g̐K\ (m'', s''', split(''), split(m'') and qr'')
+
+=item * _uNH[g̐K\ (//, m//, ??, s///, split(//), split(m//) and qr//)
+
+=item * tr/// ̒̕ (tr/// and y///)
+
+=back
+
+  : J^Jíu\vR[h "\x83\x5C"
+  
+                    _v
+  -----------------------------------------
+  source script   "`/"    [83 5c]
+  -----------------------------------------
+ 
+   use Sjis; s
+                          _v
+  -----------------------------------------
+  escaped script  "`\/"   [83 [5c] 5c]
+  -----------------------------------------
+                    ^--- Sjis \tgEFAŃGXP[v
+ 
+  Ql              _v
+  -----------------------------------------
+  your eye's      "`/\"   [83 5c] [5c]
+  -----------------------------------------
+  perl eye's      "`\/"   [83] \[5c]
+  -----------------------------------------
+ 
+                          _v
+  -----------------------------------------
+  in the perl     "`/"    [83] [5c]
+  -----------------------------------------
+
+=head1 NX̃GXP[v
 
 ߋperlƂ̌݊ۂ߂ɕNX͈ȉ̂悤ɍĒ`Ă܂B
 
   ---------------------------------------------------------------------------
   escape        class
   ---------------------------------------------------------------------------
+   .            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x0A])
+                (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[\x00-\xFF]) (/s Cq)
   \d            [0-9]
   \s            [\x09\x0A\x0C\x0D\x20]
   \w            [0-9A-Z_a-z]
@@ -193,119 +269,114 @@ l \b  \B ߋperlƂ̌݊ۂ߂ɍĒ`Ă܂B
   \B            (?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?:(?<=[\x81-\x9F\xE0-\xFC][\x00-\xFF])|(?<=[^0-9A-Z_a-z]))(?=[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9A-Z_a-z]))
   ---------------------------------------------------------------------------
 
-=head1 JPerl ݊̋@\
+=head1 g݊֐̃GXP[v
 
-ȉ̊֐ JPerl Ɠlɋ@\܂B
-̃\tgEFAɂď֐܂B
+̃\tgEFAɂĊ֐̐擪 'Esjis::' GXP[v܂B
+Esjis::* ֐ Esjis.pm 񋟂܂B
 
-=over 2
+  ---------------------------------
+  O      
+  ---------------------------------
+  length      length
+  substr      substr
+  pos         pos
+  split       Esjis::split
+  tr///       Esjis::tr
+  tr///b      tr///
+  tr///B      tr///
+  y///        Esjis::tr
+  y///b       tr///
+  y///B       tr///
+  chop        Esjis::chop
+  index       Esjis::index
+  rindex      Esjis::rindex
+  lc          Esjis::lc
+  uc          Esjis::uc
+  chr         Esjis::chr
+  glob        Esjis::glob
+  lstat       Esjis::lstat
+  opendir     Esjis::opendir
+  stat        Esjis::stat
+  unlink      Esjis::unlink
+  chdir       Esjis::chdir
+  do          Esjis::do
+  require     Esjis::require
+  ---------------------------------
 
-=item * VONH[g2INebgR[ḧ
+  ------------------------------------------------------------------------------------------------------------------------
+  O                   
+  ------------------------------------------------------------------------------------------------------------------------
+  use Perl::Module;        BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->import() if Perl::Module->can('import'); }
+  use Perl::Module @list;  BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->import(@list) if Perl::Module->can('import'); }
+  use Perl::Module ();     BEGIN { Esjis::require 'Perl/Module.pm'; }
+  no Perl::Module;         BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->unimport() if Perl::Module->can('unimport'); }
+  no Perl::Module @list;   BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->unimport(@list) if Perl::Module->can('unimport'); }
+  no Perl::Module ();      BEGIN { Esjis::require 'Perl/Module.pm'; }
+  ------------------------------------------------------------------------------------------------------------------------
 
-=item * _uNH[g2INebgR[ḧ
+=head1 t@CeXgZq̃GXP[v
 
-=item * VONH[g2INebgR[hK\̈
+̃\tgEFAɂĊ֐̉Zq '-'  'Esjis::' ɏ܂B
 
-=item * _uNH[g2INebgR[hK\̈
+  ---------------------------------
+  O      
+  ---------------------------------
+  -r          Esjis::r
+  -w          Esjis::w
+  -x          Esjis::x
+  -o          Esjis::o
+  -R          Esjis::R
+  -W          Esjis::W
+  -X          Esjis::X
+  -O          Esjis::O
+  -e          Esjis::e
+  -z          Esjis::z
+  -f          Esjis::f
+  -d          Esjis::d
+  -l          Esjis::l
+  -p          Esjis::p
+  -S          Esjis::S
+  -b          Esjis::b
+  -c          Esjis::c
+  -t          Esjis::t
+  -u          Esjis::u
+  -g          Esjis::g
+  -k          Esjis::k
+  -T          Esjis::T
+  -B          Esjis::B
+  -s          Esjis::s
+  -M          Esjis::M
+  -A          Esjis::A
+  -C          Esjis::C
+  ---------------------------------
 
-=item * chop  Esjis::chop ɏ܂
+=head1 ֐̃GXP[v
 
-=item * split  Esjis::split ɏ܂
+ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
+̋@\ɂẮuẘ֐vQƂĂB
 
-=item * length ͂̂܂܂ł
+  ---------------------------------
+  oCgw  w
+  ---------------------------------
+  ord         Sjis::ord
+  reverse     Sjis::reverse
+  length      Sjis::length
+  substr      Sjis::substr
+  index       Sjis::index
+  rindex      Sjis::rindex
+  ---------------------------------
 
-=item * substr ͂̂܂܂ł
+=head1 g݂̕WW[̃GXP[v
 
-=item * index  Esjis::index ɏ܂
+Esjis.pm ̐擪 "BEGIN { unshift @INC, '/Perl/site/lib/Sjis' }" sA
+W[̌Aŏ '/Perl/site/lib/Sjis' QƂ悤ɂȂ܂BSjis
+\tgEFAŎg悤ɉWW[Ɋi[āAƂ̕W
+W[I[o[Ch܂B
 
-=item * rindex  Esjis::rindex ɏ܂
+=head1 WW[̓ẽGXP[v
 
-=item * pos ͂̂܂܂ł
-
-=item * lc  Esjis::lc ܂ Esjis::lc_ ɏ܂
-
-=item * uc  Esjis::uc ܂ Esjis::uc_ ɏ܂
-
-=item * ord ͂̂܂܂ł(C|[gȂꍇ)
-
-=item * reverse ͂̂܂܂ł(C|[gȂꍇ)
-
-=item * tr/// ܂ y///  Esjis::tr ɏ܂
-
-    /b  /B Cqpł܂B
-
-=item * chdir  Esjis::chdir ɏ܂
-
-    MSWin32 ̏ꍇ perl5.005 Ɍ蕶R[h(0x5C)ŏIpX
-    ł܂B
-
-=item * do file  Esjis::do file ɏ܂
-
-=item * require  Esjis::require ɏ܂
-
-=item * use Perl::Module @list; 
-
-    BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->import(@list); } 
-    ܂B
-
-=item * use Perl::Module (); 
-
-    BEGIN { Esjis::require 'Perl/Module.pm'; } ɏ܂B
-
-=back
-
-=head1 JPerl Əʌ݊̋@\
-
-ȉ̋@\ JPerl Əʌ݊łB
-
-=over 2
-
-=item * chr  Esjis::chr ܂ Esjis::chr_ ɏ܂
-
-    2INebgR[hɑΉĂ܂B
-
-=item * -X (t@CeXgZq)  Esjis::X ܂ Esjis::X_ ɏ܂
-
-    ႦΓǎ\ǂeXg -r  Esjis::r ɂȂ܂B
-
-    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B
-
-=item * glob  Esjis::glob ܂ Esjis::glob_ ɏ܂
-
-    @glob = Esjis::glob($string);
-    @glob = Esjis::glob_;
-
-    Esjis::glob ́AOSԂŉ̂gꂽDOSOu(ChJ[h)
-    @\񋟂܂BfBNgpXɂChJ[hgpłA啶
-    ̋ʂȂAtXbVƃXbVgpł܂(
-    tXbV2dɂȂ΂Ȃ܂)B
-
-    s@́A
-
-    use Sjis;
-    @perlfiles = glob  "..\pe?l/*.p?";
-    print <..\pe?l/*.p?>;
-
-    "~" ݂͌̃[Ũz[fBNgɓWJ܂B
-    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B
-
-=item * lstat  Esjis::lstat ܂ Esjis::lstat_ ɏ܂
-
-    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B
-
-=item * opendir  Esjis::opendir ɏ܂
-
-    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B
-
-=item * stat  Esjis::stat ܂ Esjis::stat_ ɏ܂
-
-    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B
-
-=item * unlink  Esjis::unlink ɏ܂
-
-    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B
-
-=back
+WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;' 
+'use Sjis;' ɏ܂BKvɉĂ̑̏sĂB
 
 =head1 ẘ֐
 
@@ -464,6 +535,12 @@ oO񍐁Apb`}܂B
 
     IWi Perl Ƌ@\ł(ShiftJIS ɑΉĂ܂)B
 
+=item * m/$re/o, s/$re/foo/o, qr/$re/o  /o Cq
+
+    perl5.006 ɂ /o CqҒʂ̓܂łBϐ $re ̒l
+    ύXƎ̎sɂ̕ύXf܂Bł /o gƂ $re
+    ̓eύXȂł傤AۂɖɂȂ邱Ƃ͂Ȃł傤B
+
 =item * chdir
 
     MSWin32  perl5.006, perl5.008, perl5.010, perl5.012 ɂĕR[h(0x5C)
@@ -474,11 +551,16 @@ oO񍐁Apb`}܂B
     chdir does not work with chr(0x5C) at end of path
     http://bugs.activestate.com/show_bug.cgi?id=81839
 
-=item * m/$re/o, s/$re/foo/o, qr/$re/o  /o Cq
+=item * ǂ݌
 
-    perl5.006 ɂ /o CqҒʂ̓܂łBϐ $re ̒l
-    ύXƎ̎sɂ̕ύXf܂Bł /o gƂ $re
-    ̓eύXȂł傤AۂɖɂȂ邱Ƃ͂Ȃł傤B
+    ǂ݌(Ⴆ (?<=[A-Z]))O̓oCg̑oCgɌă}b`
+    邱Ƃɂ͑ΏĂ܂B
+    Ⴆ΁A'ACE' =~ /(?<=[A-Z])([ACE])/ sƃ}b` $1  'C'
+    ɂȂ܂A͐܂B
+
+=item * ӒlƂĂ Sjis::substr
+
+Sjis::substr  CORE::substr Ƃ͈قȂAӒlƂĈƂł܂B
 
 =item * ϐ $`  $& ͋@\܂
 
@@ -493,8 +575,8 @@ oO񍐁Apb`}܂B
  
     ̕ $& Ɋ܂܂Ă܂łB
     L̎sʂ͈ȉ̂悤ɂȂ܂B 
-      $'  ''       ('AAA' ])
-      $&  'AAABBB' ('BBB' ])
+      $'  ''       ('AAA' )
+      $&  'AAABBB' ('BBB' )
       $`  'CCC'
  
     @
@@ -518,7 +600,6 @@ oO񍐁Apb`}܂B
 =head1 
 
 ̃vWFNg t  ina@cpan.org ɂĎn܂܂B
-̃t@C𕪂܂傤B
 
 =head1 쌠
 
@@ -1102,13 +1183,13 @@ zIɂ́Aȉ5̃S[悤ƍlĂ܂B
 
                                    GOAL#1  GOAL#2
                             (a)     (b)     (c)     (d)     (e)
-         
-          f[^        Old   Old   New   Old   New  
-         
-          XNvg    Old       Old           New      
-         
-          C^v^  Old               New              
-         
+          +--------------+-------+-------+-------+-------+-------+
+          | data         |  Old  |  Old  |  New  |  Old  |  New  |
+          +--------------+-------+-------+-------+-------+-------+
+          | script       |  Old  |      Old      |      New      |
+          +--------------+-------+---------------+---------------+
+          | interpreter  |  Old  |              New              |
+          +--------------+-------+-------------------------------+
           Old --- ̃oCgw
           New --- Vw
 
@@ -1117,14 +1198,14 @@ zIɂ́Aȉ5̃S[悤ƍlĂ܂B
     ̃\tgEFAAё݂Ă JPerl Ă݂܂傤B
 
                             (a)     (b)     (c)     (d)     (e)
-                                           JPerl          Encode,Sjis
-         
-          f[^        Old   Old   New   Old   New  
-         
-          XNvg    Old       Old           New      
-         
-          C^v^  Old               New              
-         
+                                          JPerl           Encode,Sjis
+          +--------------+-------+-------+-------+-------+-------+
+          | data         |  Old  |  Old  |  New  |  Old  |  New  |
+          +--------------+-------+-------+-------+-------+-------+
+          | script       |  Old  |      Old      |      New      |
+          +--------------+-------+---------------+---------------+
+          | interpreter  |  Old  |              New              |
+          +--------------+-------+-------------------------------+
           Old --- ̃oCgw
           New --- Vw
 
@@ -1160,21 +1241,22 @@ zIɂ́Aȉ5̃S[悤ƍlĂ܂B
     葱ׂłB
 
     JPerl  Perl 𕪊򂳂Ȃ悤ɂ邽߂ɁAC^v^𕪊򂳂܂B
-    ł Perl RA`[̓C^v^̕]łȂ̂ł傤B
+    ł Perl RA`[̓C^v^̕]łȂ̂ł傤BʓIPerl
+    ꂪ򂵁AR~jeB͏k]VȂ܂B
 
-    oCgw Perl ͂łɃoCif[^Ƃł邽߁Aw
-    Perl ʗĂō쐬Kv͂܂B̃\tgEFA͒PȂ Perl ̃Av
+    oCgw perl ͂łɃoCif[^Ƃł邽߁Aw
+    perl ʗĂō쐬Kv͂܂B̃\tgEFA͒PȂ Perl ̃Av
     P[VvOłAtB^vOƂč쐬Ă܂B
     {Iɂ perl słȂΓ삷ł傤B
 
-    ɖ perl XNvgŉȂAPerl R~jeBT|[g
-    邱Ƃł傤B
+    ɖ Perl XNvgŉ悤ƂȂAPerl R~jeB̃T|[g
+    𓾂ł傤B
 
 =item * S[5
 
     JPerl [U Perl  JPerl ێł悤ɂȂB
 
-    ԂAĂƁB
+    JPerl Ȃ̂΂ɂ܂悤 ...
 
 =back
 
@@ -1329,6 +1411,7 @@ vO~O񋟂܂B
 
  A ms, Shift-JISeLXg𐳂
  http://homepage1.nifty.com/nomenclator/perl/shiftjis.htm
+ http://search.cpan.org/dist/ShiftJIS-Regexp/
 
  ܂ 䂫Ђ낳, Ruby on Perl(s)
  http://www.rubyist.net/~matz/slides/yapc2006/
@@ -1352,6 +1435,11 @@ vO~O񋟂܂B
  http://search.cpan.org/~watanabe/
  ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 
+ Ί_ ꂳ, Pod-PerldocJp, _Perl̐Eւ悤
+ http://search.cpan.org/dist/Pod-PerldocJp/
+ http://gihyo.jp/dev/serial/01/modern-perl/0031
+ http://gihyo.jp/dev/serial/01/modern-perl/0032
+
   e, Encode W[
  http://search.cpan.org/dist/Encode/
 
